pub struct Coin {
pub id: String,
pub name: String,
pub symbol: String,
pub rank: isize,
pub is_new: bool,
pub is_active: bool,
pub coin_type: String,
}Expand description
Basic information about cryptocurrencies on coinpaprika.com
Fields
id: StringID of coin on coinpaprika.com
name: StringName of the cryptocurrency
symbol: StringSymbol of the cryptocurrency
rank: isizeCurrent ranking of the cryptocurrency. If is_active is false the rank is 0
is_new: boolFlag indicating if the currency was added within the last 5 days
is_active: boolFlag indicating if the currency is active, which means that we can calculate the current price and volume
coin_type: StringType of the cryptocurrency. Currently supported values are coin and token